@@ -1,8 +1,9 @@
 use Test::More;
 
-package Test::DBO;
+package # Hide from PAUSE
+    Test::DBO;
 
-use 5.010_000;
+use 5.008;
 use strict;
 use warnings;
 
@@ -55,8 +56,25 @@ sub import {
     $dbd_name = shift;
     my %opt = splice @_;
 
-    grep $_ eq $dbd, DBI->available_drivers or
-        plan skip_all => "No $dbd driver available!";
+    grep $_ eq $dbd, DBI->available_drivers
+        or plan skip_all => "No $dbd driver available!";
+
+    # Skip tests with missing module requirements
+    unless (eval { DBIx::DBO->_require_dbd_class($dbd) }) {
+        if ($@ =~ /^Can't load \Q$dbd\E driver\nCan't locate ([\w\/]+)\.pm in \@INC /) {
+            # Module is not installed
+            ($_ = $1) =~ s'/'::'g;
+        } elsif ($@ =~ /^Can't load \Q$dbd\E driver\n([\w:]+ version [\d\.]+) required/) {
+            # Module is not correct version
+            ($_ = $1);
+        } elsif ($@ =~ /^Can't load \Q$dbd\E driver\n\Q$dbd_name\E is not yet supported/) {
+            # DBM is not yet supported
+            plan skip_all => "Can't load $dbd driver: $dbd_name is not yet supported";
+        } else {
+            die $@;
+        }
+        plan skip_all => "Can't load $dbd driver: $_ is required";
+    }
 
     {
         no strict 'refs';
@@ -82,7 +100,7 @@ sub import {
 
         plan tests => $opt{tests};
         pass "Connect to $dbd_name";
-        isa_ok $$dbo_ref, "DBIx::DBO::DBD::${dbd}::Handle", '$dbo';
+        isa_ok $$dbo_ref, "DBIx::DBO::DBD::${dbd}", '$dbo';
     } else {
         plan tests => $opt{tests};
     }
@@ -103,14 +121,18 @@ sub sql_err {
 
 sub connect_ok {
     ok my $dbo = connect_dbo(@_), "Connect to $dbd_name" or die $DBI::errstr;
-    isa_ok $dbo, "DBIx::DBO::DBD::${dbd}::Handle", '$dbo';
+    isa_ok $dbo, "DBIx::DBO::DBD::${dbd}", '$dbo';
     return $dbo;
 }
 
 sub connect_dbo {
-    my $dsn = shift // $ENV{'DBO_TEST_'.uc($dbd).'_DB'} // '';
-    my $user = shift // $ENV{'DBO_TEST_'.uc($dbd).'_USER'};
-    my $pass = shift // $ENV{'DBO_TEST_'.uc($dbd).'_PASS'};
+    my $dsn = shift;
+    defined $dsn or $dsn = $ENV{'DBO_TEST_'.uc($dbd).'_DB'};
+    defined $dsn or $dsn = '';
+    my $user = shift;
+    defined $user or $user = $ENV{'DBO_TEST_'.uc($dbd).'_USER'};
+    my $pass = shift;
+    defined $pass or $pass = $ENV{'DBO_TEST_'.uc($dbd).'_PASS'};
 
     DBIx::DBO->connect("DBI:$dbd:$dsn", $user, $pass, {RaiseError => 0});
 }
@@ -290,7 +312,10 @@ sub query_methods {
     # Fetch the first row
     $r = $q->fetch;
     ok $r->isa('DBIx::DBO::Row'), 'Method DBIx::DBO::Query->fetch';
-    is $r_str, "$r", 'Re-use the same row object';
+    SKIP: {
+        skip "Re-use row doesn't work with Devel::Cover", 1 if exists $INC{'Devel/Cover.pm'};
+        is $r_str, "$r", 'Re-use the same row object';
+    }
 
     # Access methods
     is $r->{name}, 'John Doe', 'Access row as a hashref';
@@ -309,6 +334,14 @@ sub query_methods {
     1 while $q->fetch;
     is $q->rows, 6, 'Row count is 6';
 
+    # Reset the Query
+    $q->reset;
+    is $q->sql, $dbo->query($t)->sql, 'Method DBIx::DBO::Query->reset';
+
+    # Group by the first initial
+    $q->show({FUNC => 'SUBSTRING(?, 1, 1)', COL => 'name', AS => 'initial'});
+    ok(($q->group_by('initial'), $q->run), 'Method DBIx::DBO::Query->group_by') or diag sql_err($q);
+
     $q->finish;
     return $q;
 }
@@ -317,9 +350,11 @@ sub advanced_query_methods {
     my $dbo = shift;
     my $t = shift;
     my $q = shift;
+    $q->reset;
 
     # Show specific columns only
     $q->show({ FUNC => 'UPPER(?)', COL => 'name', AS => 'name' }, 'id', 'name');
+    $q->order_by('id');
     is $q->fetch->{name}, 'JOHN DOE', 'Method DBIx::DBO::Query->show';
     is $q->row ** $t ** 'name', 'John Doe', 'Access specific column';
 
@@ -423,17 +458,17 @@ sub Dump {
             $var = 'r';
         }
     }
-    $var //= 'dump';
+    defined $var or $var = 'dump';
     require Data::Dumper;
     my $d = Data::Dumper->new([$val], [$var]);
     my %seen;
-    @_no_recursion = ($val);
-    given (reftype $val) {
-        when ('ARRAY') { _Find_Seen(\%seen, $_) for @$val }
-        when ('HASH')  { _Find_Seen(\%seen, $_) for values %$val }
-        when ('REF')   { _Find_Seen(\%seen, $$val) }
+    if (defined $val) {
+        @_no_recursion = ($val);
+        if (reftype $val eq 'ARRAY')   { _Find_Seen(\%seen, $_) for @$val }
+        elsif (reftype $val eq 'HASH') { _Find_Seen(\%seen, $_) for values %$val }
+        elsif (reftype $val eq 'REF')  { _Find_Seen(\%seen, $$val) }
+        $d->Seen(\%seen);
     }
-    $d->Seen(\%seen);
     warn $d->Dump;
 }
 
@@ -467,11 +502,9 @@ sub _Find_Seen {
             return;
         }
     }
-    given (reftype $val) {
-        when ('ARRAY') { _Find_Seen($seen, $_) for @$val }
-        when ('HASH')  { _Find_Seen($seen, $_) for values %$val }
-        when ('REF')   { _Find_Seen($seen, $$val) }
-    }
+    if (reftype $val eq 'ARRAY')   { _Find_Seen($seen, $_) for @$val }
+    elsif (reftype $val eq 'HASH') { _Find_Seen($seen, $_) for values %$val }
+    elsif (reftype $val eq 'REF')  { _Find_Seen($seen, $$val) }
 }
 
 1;
