@@ -1,37 +1,15 @@
-package DBIx::DBO::Common;
+package # hide from PAUSE
+    DBIx::DBO::Common;
 
-use 5.010;
+use 5.008;
 use strict;
 use warnings;
 use Carp;
 use Scalar::Util 'blessed';
 use constant PLACEHOLDER => "\x{b1}\x{a4}\x{221e}";
 
-=head1 NAME
-
-DBIx::DBO::Common - Common routines and variables exported to all DBO classes.
-
-=head1 DESCRIPTION
-
-This module automatically exports ALL the methods and variables for use in the other DBO modules.
-
-=head2 do
-
-  $dbo->do($statement)         or die $dbo->dbh->errstr;
-  $dbo->do($statement, \%attr) or die $dbo->dbh->errstr;
-  $dbo->do($statement, \%attr, @bind_values) or die ...
-
-This provides access to DBI C<do> method.
-
-=head2 dbh
-
-The read-write DBI handle.
-
-=head2 rdbh
-
-The read-only DBI handle, or if there is no read-only connection, the read-write DBI handle.
-
-=cut
+# Common routines and variables exported to all DBO classes.
+# This module automatically exports ALL the methods and variables for use in the other DBO modules.
 
 use subs qw(ouch oops);
 *oops = \&Carp::carp;
@@ -182,9 +160,9 @@ sub _build_from {
     my $h = shift;
     return $h->{from} if defined $h->{from};
     undef @{$h->{From_Bind}};
-    $h->{from} = $me->_build_table(($me->_tables)[0]);
-    for (my $i = 1; $i < $me->_tables; $i++) {
-        $h->{from} .= $h->{Join}[$i].$me->_build_table(($me->_tables)[$i]);
+    $h->{from} = $me->_build_table(($me->tables)[0]);
+    for (my $i = 1; $i < $me->tables; $i++) {
+        $h->{from} .= $h->{Join}[$i].$me->_build_table(($me->tables)[$i]);
         if ($h->{JoinOn}[$i]) {
             $h->{from} .= ' ON '.join(' AND ', $me->_build_where_chunk($h->{From_Bind}, 'OR', $h->{JoinOn}[$i]));
         }
@@ -192,19 +170,29 @@ sub _build_from {
     $h->{from};
 }
 
-sub _parse_col {
+sub _valid_col {
     my ($me, $col) = @_;
-    if (blessed $col and $col->isa('DBIx::DBO::Column')) {
-        for my $tbl ($me->_tables) {
-            return $col if $col->[0] == $tbl;
-        }
-        # TODO: Flesh out this ouch a bit
-        ouch 'Invalid table';
+    for my $tbl ($me->tables) {
+        return $col if $col->[0] == $tbl;
     }
-    ouch 'Invalid column: '.$col if ref $col;
-    for my $tbl ($me->_tables) {
+    ouch 'Invalid column, the column is from a table not included in this query';
+}
+
+sub _parse_col {
+    my ($me, $col, $_chk_aliases) = @_;
+    if (ref $col) {
+        return $me->_valid_col($col) if blessed $col and $col->isa('DBIx::DBO::Column');
+        ouch 'Invalid column: '.$col;
+    }
+    for my $tbl ($me->tables) {
         return $tbl->column($col) if exists $tbl->{Column_Idx}{$col};
     }
+    if ($_chk_aliases) {
+        for my $fld (@{$me->{build_data}{Showing}}) {
+            return \($me->_qi($col))
+                if !blessed $fld and exists $fld->[2]{AS} and $col eq $fld->[2]{AS};
+        }
+    }
     ouch 'No such column: '.$col;
 }
 
@@ -216,12 +204,12 @@ sub _build_col {
 sub _parse_val {
     my $me = shift;
     my $fld = shift;
-    my $check_fld = shift || '';
+    my %c = (Check => '', @_);
 
     my $func;
     my %opt;
     if (ref $fld eq 'SCALAR') {
-        ouch 'Invalid '.($check_fld eq 'Column' ? 'column' : 'field').' reference (scalar ref to undef)'
+        ouch 'Invalid '.($c{Check} eq 'Column' ? 'column' : 'field').' reference (scalar ref to undef)'
             unless defined $$fld;
         $func = $$fld;
         $fld = [];
@@ -235,10 +223,12 @@ sub _parse_val {
         $opt{COLLATE} = $fld->{COLLATE} if exists $fld->{COLLATE};
         if (exists $fld->{COL}) {
             ouch 'Invalid HASH containing both COL and VAL' if exists $fld->{VAL};
-            $fld = $me->_parse_col($fld->{COL});
+            $fld = $me->_parse_col($fld->{COL}, $c{Aliases});
         } else {
             $fld = exists $fld->{VAL} ? $fld->{VAL} : [];
         }
+    } elsif (blessed $fld and $fld->isa('DBIx::DBO::Column')) {
+        return [ $me->_valid_col($fld) ];
     }
     $fld = [$fld] unless ref $fld eq 'ARRAY';
 
@@ -247,8 +237,8 @@ sub _parse_val {
     if (defined $func) {
         my $need = $me->_substitute_placeholders($func);
         ouch "The number of params ($with) does not match the number of placeholders ($need)" if $need != $with;
-    } elsif ($with != 1 and $check_fld ne 'Auto') {
-        ouch 'Invalid '.($check_fld eq 'Column' ? 'column' : 'field')." reference (passed $with params instead of 1)";
+    } elsif ($with != 1 and $c{Check} ne 'Auto') {
+        ouch 'Invalid '.($c{Check} eq 'Column' ? 'column' : 'field')." reference (passed $with params instead of 1)";
     }
     return ($fld, $func, \%opt);
 }
@@ -321,13 +311,13 @@ sub _build_where_chunk {
                     # Right now this starts with the last @whs and works backwards
                     # It splices when the ag is the correct AND/OR and the funcs match and all flds match
                     next if (ref $whs[$i][0] or $ag ne ($whs[$i][7] || _op_ag($whs[$i][0])));
-#                    no warnings 'uninitialized';
-#                    next if $whs[$i][2] ne $fld_func;
-#                    use warnings 'uninitialized';
-                    next unless $fld_func ~~ $whs[$i][2];
-#                    my $l = $whs[$i][1];
-#                    next if ((ref $l eq 'ARRAY' ? "@$l" : $l) ne (ref $fld eq 'ARRAY' ? "@$fld" : $fld));
-                    next unless $fld ~~ $whs[$i][1];
+                    no warnings 'uninitialized';
+                    next if $whs[$i][2] ne $fld_func;
+                    use warnings 'uninitialized';
+#                    next unless $fld_func ~~ $whs[$i][2];
+                    my $l = $whs[$i][1];
+                    next if ((ref $l eq 'ARRAY' ? "@$l" : $l) ne (ref $fld eq 'ARRAY' ? "@$fld" : $fld));
+#                    next unless $fld ~~ $whs[$i][1];
                     push @ary, $me->_build_where_piece($bind, @{splice @whs, $i, 1});
                 }
             }
