@@ -65,7 +65,7 @@ sub _new {
     for my $table (@_) {
         $me->join_table($table);
     }
-    $me->_blank;
+    $me->reset;
     return wantarray ? ($me, $me->tables) : $me;
 }
 
@@ -134,19 +134,22 @@ sub _table_alias {
     @{$me->{Tables}} > 1 ? 't'.($i + 1) : ();
 }
 
-sub _showing {
-    my $me = shift;
-    @{$me->{build_data}{Showing}} ? @{$me->{build_data}{Showing}} : @{$me->{Tables}};
-}
+=head2 reset
 
-sub _blank {
+  $query->reset;
+
+Reset the query, start over with a clean slate.
+
+=cut
+
+sub reset {
     my $me = shift;
     $me->unwhere;
 #    $me->{IsDistinct} = 0;
-    undef @{$me->{build_data}{Showing}};
-    undef @{$me->{build_data}{GroupBy}};
-    undef @{$me->{build_data}{OrderBy}};
-    undef $me->{build_data}{LimitOffset};
+    $me->show;
+    $me->group_by;
+    $me->order_by;
+    $me->limit;
 }
 
 =head2 show
@@ -207,7 +210,7 @@ sub join_on {
     undef $me->{build_data}{from};
 
     $me->{build_data}{Join}[$i] = ' JOIN ' if $me->{build_data}{Join}[$i] eq ', ';
-    $me->_add_where($me->{build_data}{JoinOn}[$i] //= [], $op,
+    $me->_add_where($me->{build_data}{JoinOn}[$i] ||= [], $op,
         $col1, $col1_func, $col1_opt, $col2, $col2_func, $col2_opt, @_);
 }
 
@@ -250,7 +253,7 @@ sub where {
     # If the $fld is just a scalar use it as a column name not a value
     my ($fld, $fld_func, $fld_opt) = $me->_parse_col_val(shift);
     my $op = shift;
-    my ($val, $val_func, $val_opt) = $me->_parse_val(shift, 'Auto');
+    my ($val, $val_func, $val_opt) = $me->_parse_val(shift, Check => 'Auto');
 
     # Validate the fields
     for my $f (@$fld, @$val) {
@@ -266,7 +269,7 @@ sub where {
     undef $me->{build_data}{where};
 
     # Find the current Where_Data reference
-    my $ref = $me->{build_data}{Where_Data} //= [];
+    my $ref = $me->{build_data}{Where_Data} ||= [];
     $ref = $ref->[$_] for (@{$me->{Bracket_Refs}});
 
     $me->_add_where($ref, $op, $fld, $fld_func, $fld_opt, $val, $val_func, $val_opt, @_);
@@ -379,11 +382,9 @@ sub _add_where {
 sub _parse_col_val {
     my $me = shift;
     my $col = shift;
-    return $me->_parse_val($col, 'Column') if ref $col;
-    for my $tbl ($me->tables) {
-        return [ $tbl->column($col) ] if exists $tbl->{Column_Idx}{$col};
-    }
-    ouch 'No such column: '.$col;
+    my %c = (Check => 'Column', @_);
+    return $me->_parse_val($col, %c) if ref $col;
+    return [ $me->_parse_col($col, $c{Aliases}) ];
 }
 
 =head2 group_by
@@ -403,7 +404,7 @@ sub group_by {
     undef $me->{build_data}{group};
     undef @{$me->{build_data}{GroupBy}};
     for my $col (@_) {
-        my @group = $me->_parse_col_val($col);
+        my @group = $me->_parse_col_val($col, Aliases => 1);
         push @{$me->{build_data}{GroupBy}}, \@group;
     }
 }
@@ -425,7 +426,7 @@ sub order_by {
     undef $me->{build_data}{order};
     undef @{$me->{build_data}{OrderBy}};
     for my $col (@_) {
-        my @order = $me->_parse_col_val($col);
+        my @order = $me->_parse_col_val($col, Aliases => 1);
         push @{$me->{build_data}{OrderBy}}, \@order;
     }
 }
@@ -552,7 +553,7 @@ Returns the L<DBIx::DBO::Row|DBIx::DBO::Row> object for the current row from the
 sub row {
     my $me = shift;
     $me->sql; # Detach if needed
-    $me->{Row} //= $me->{DBO}->row($me);
+    $me->{Row} ||= $me->{DBO}->row($me);
 }
 
 =head2 run
@@ -739,7 +740,7 @@ When setting an option, the previous value is returned.
 sub config {
     my $me = shift;
     my $opt = shift;
-    my $val = $me->{Config}{$opt} // $me->{DBO}->config($opt);
+    my $val = defined $me->{Config}{$opt} ? $me->{Config}{$opt} : $me->{DBO}->config($opt);
     $me->{Config}{$opt} = shift if @_;
     return $val;
 }
