@@ -120,16 +120,11 @@ sub _table_alias {
     @{$$me->{Tables}} > 1 ? 't'.($i + 1) : ();
 }
 
-sub _showing {
-    my $me = shift;
-    @{$$me->{build_data}{Showing}} ? @{$$me->{build_data}{Showing}} : @{$$me->{Tables}};
-}
-
 sub _column_idx {
     my $me = shift;
     my $col = shift;
     my $idx = -1;
-    for my $shown ($me->_showing) {
+    for my $shown (@{$$me->{build_data}{Showing}} ? @{$$me->{build_data}{Showing}} : @{$$me->{Tables}}) {
         if (blessed $shown and $shown->isa('DBIx::DBO::Table')) {
             if ($col->[0] == $shown and exists $shown->{Column_Idx}{$col->[1]}) {
                 return $idx + $shown->{Column_Idx}{$col->[1]};
@@ -295,7 +290,8 @@ When setting an option, the previous value is returned.
 sub config {
     my $me = shift;
     my $opt = shift;
-    my $val = $$me->{Config}{$opt} // $$me->{DBO}->config($opt);
+    my $val = defined $$me->{Config}{$opt} ? $$me->{Config}{$opt} :
+        (defined $$me->{Parent} ? $$me->{Parent} : $$me->{DBO})->config($opt);
     $$me->{Config}{$opt} = shift if @_;
     return $val;
 }
